==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/sector/bg/_0204/LFTTabel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.DatumMetIndicatorKerngegeven;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * tabel entiteit lifttype
 * 
 * <p>Java class for LFT-tabel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LFT-tabel">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="code" minOccurs="0">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>CodeLiftType">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="omschrijving" minOccurs="0">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>OmschrijvingLiftType">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="ingangsdatum" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/>
 *         &lt;element name="einddatum" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/>
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}tabel"/>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LFT-tabel", propOrder = {
    "code",
    "omschrijving",
    "ingangsdatum",
    "einddatum",
    "extraElementen"
})
public class LFTTabel {

    @XmlElementRef(name = "code", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<LFTTabel.Code> code;
    @XmlElementRef(name = "omschrijving", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<LFTTabel.Omschrijving> omschrijving;
    @XmlElementRef(name = "ingangsdatum", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> ingangsdatum;
    @XmlElementRef(name = "einddatum", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> einddatum;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Code }{@code >}
     *     
     */
    public JAXBElement<LFTTabel.Code> getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Code }{@code >}
     *     
     */
    public void setCode(JAXBElement<LFTTabel.Code> value) {
        this.code = value;
    }

    /**
     * Gets the value of the omschrijving property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Omschrijving }{@code >}
     *     
     */
    public JAXBElement<LFTTabel.Omschrijving> getOmschrijving() {
        return omschrijving;
    }

    /**
     * Sets the value of the omschrijving property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Omschrijving }{@code >}
     *     
     */
    public void setOmschrijving(JAXBElement<LFTTabel.Omschrijving> value) {
        this.omschrijving = value;
    }

    /**
     * Gets the value of the ingangsdatum property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getIngangsdatum() {
        return ingangsdatum;
    }

    /**
     * Sets the value of the ingangsdatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setIngangsdatum(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.ingangsdatum = value;
    }

    /**
     * Gets the value of the einddatum property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getEinddatum() {
        return einddatum;
    }

    /**
     * Sets the value of the einddatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setEinddatum(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.einddatum = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "T";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>CodeLiftType">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Code {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>OmschrijvingLiftType">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Omschrijving {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/LFTTabel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.DatumMetIndicatorKerngegeven;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * tabel entiteit lifttype
 * 
 * <p>Java class for LFT-tabel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LFT-tabel"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="code" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;CodeLiftType"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="omschrijving" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;OmschrijvingLiftType"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="ingangsdatum" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/&gt;
 *         &lt;element name="einddatum" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/&gt;
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}tabel"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LFT-tabel", propOrder = {
    "code",
    "omschrijving",
    "ingangsdatum",
    "einddatum",
    "extraElementen"
})
public class LFTTabel {

    @XmlElementRef(name = "code", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<LFTTabel.Code> code;
    @XmlElementRef(name = "omschrijving", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<LFTTabel.Omschrijving> omschrijving;
    @XmlElementRef(name = "ingangsdatum", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> ingangsdatum;
    @XmlElementRef(name = "einddatum", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> einddatum;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Code }{@code >}
     *     
     */
    public JAXBElement<LFTTabel.Code> getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Code }{@code >}
     *     
     */
    public void setCode(JAXBElement<LFTTabel.Code> value) {
        this.code = value;
    }

    /**
     * Gets the value of the omschrijving property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Omschrijving }{@code >}
     *     
     */
    public JAXBElement<LFTTabel.Omschrijving> getOmschrijving() {
        return omschrijving;
    }

    /**
     * Sets the value of the omschrijving property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link LFTTabel.Omschrijving }{@code >}
     *     
     */
    public void setOmschrijving(JAXBElement<LFTTabel.Omschrijving> value) {
        this.omschrijving = value;
    }

    /**
     * Gets the value of the ingangsdatum property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getIngangsdatum() {
        return ingangsdatum;
    }

    /**
     * Sets the value of the ingangsdatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setIngangsdatum(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.ingangsdatum = value;
    }

    /**
     * Gets the value of the einddatum property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getEinddatum() {
        return einddatum;
    }

    /**
     * Sets the value of the einddatum property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setEinddatum(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.einddatum = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "T";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;CodeLiftType"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Code {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;OmschrijvingLiftType"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Omschrijving {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}
